package com.ruoyi.platform.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.platform.domain.PlatformPost;
import com.ruoyi.platform.domain.dto.PlatformPostDTO;
import com.ruoyi.platform.domain.vo.PlatformPostVO;

import java.util.List;

/**
 *@Description 岗位信息 服务层
 *@Author zhushuyong
 *@Date 2021/5/27 21:31
 *@since:
 *@copyright: 版权所有2021 开源组织 gitee(https://gitee.com/jinzheyi)作者：朱述勇<br/>
 *            GitHub(https://github.com/jinzheyi)作者：朱述勇 。
 */
public interface IPlatformPostService extends IService<PlatformPost> {

    /**
     * 查询岗位信息集合
     *
     * @param postDTO 岗位信息
     * @return 岗位信息集合
     */
    public TableDataInfo<PlatformPostVO> selectPostPage(PlatformPostDTO postDTO);

    /**
     * 查询岗位信息列表
     * @param postDTO
     * @return
     */
    List<PlatformPostVO> selectPostList(PlatformPostDTO postDTO);

    /**
     * 查询所有岗位
     *
     * @return 岗位列表
     */
    public List<PlatformPostVO> selectPostAll();

    /**
     * 根据用户ID查询岗位
     *
     * @param userId 用户ID
     * @return 岗位列表
     */
    public List<PlatformPostVO> selectPostsByUserId(String userId);

    /**
     * 通过岗位ID查询岗位信息
     *
     * @param postId 岗位ID
     * @return 角色对象信息
     */
    public PlatformPostVO selectPostById(String postId);

    /**
     * 批量删除岗位信息
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     * @throws Exception 异常
     */
    public int deletePostByIds(String ids) throws Exception;

    /**
     * 新增保存岗位信息
     *
     * @param postDTO 岗位信息
     * @return 结果
     */
    public int insertPost(PlatformPostDTO postDTO);

    /**
     * 修改保存岗位信息
     *
     * @param postDTO 岗位信息
     * @return 结果
     */
    public int updatePost(PlatformPostDTO postDTO);

    /**
     * 通过岗位ID查询岗位使用数量
     *
     * @param postId 岗位ID
     * @return 结果
     */
    public long countUserPostById(String postId);

    /**
     * 校验岗位名称
     *
     * @param postDTO 岗位信息
     * @return 结果
     */
    public String checkPostNameUnique(PlatformPostDTO postDTO);

    /**
     * 校验岗位编码
     *
     * @param postDTO 岗位信息
     * @return 结果
     */
    public String checkPostCodeUnique(PlatformPostDTO postDTO);

}
